@@ -1,17 +1,19 @@
-import smtplib
-import time
-import ssl
 import os
+import smtplib
+import ssl
+import time
+from email import encoders
+from email.mime.base import MIMEBase
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
 from enum import Enum
 from typing import List
-from imap_tools import MailBox, MailMessage, AND
+
+from imap_tools import AND, MailBox, MailMessage
 from imap_tools.mailbox import MailBoxTls
-from email.mime.multipart import MIMEMultipart
-from email.mime.base import MIMEBase
-from email.mime.text import MIMEText
-from email import encoders
+
+from .servers_config import DEFAULT_SERVERS_CONFIG, MailServers
 from .utils import if_imap_configured, if_smtp_configured
-from .servers_config import MailServers, DEFAULT_SERVERS_CONFIG
 
 
 class MailFilters(str, Enum):
@@ -311,7 +313,7 @@ class BotEmailPlugin:
     ##############
     @if_smtp_configured
     def send_message(self, subject: str, text_content: str, to_addrs: List[str], cc_addrs: List[str] = None,
-                     bcc_addrs: List[str] = None, attachments: List[str] = None) -> None:
+                     bcc_addrs: List[str] = None, attachments: List[str] = None, use_html: bool = False) -> None:
         """
         Send an email message through the SMTP protocol.
 
@@ -323,17 +325,19 @@ class BotEmailPlugin:
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
             attachments (List[str], optional): The list with the paths of the files that will be sent
                 as attachments.
+            use_html (bool): The boolean value when you want to use body in html format.
 
         Note:
             This method can only be used with an **SMTP** server configured.
         """
-        message = self.__build_message(text_content, to_addrs, cc_addrs, bcc_addrs, attachments)
+        message = self.__build_message(text_content, to_addrs, cc_addrs, bcc_addrs, attachments, use_html=use_html)
         message["Subject"] = subject
         self._smtp_mail.send_message(message)
 
     @if_smtp_configured
     def reply(self, msg: MailMessage, text_content: str, attachments: List[str] = None,
-              to_addrs: List[str] = None, cc_addrs: List[str] = None, bcc_addrs: List[str] = None) -> None:
+              to_addrs: List[str] = None, cc_addrs: List[str] = None, bcc_addrs: List[str] = None,
+              use_html: bool = False) -> None:
         """
         Reply a received email message.
 
@@ -345,17 +349,19 @@ class BotEmailPlugin:
             to_addrs (List[str], optional): The list of email addresses that will receive the message.
             cc_addrs (List[str], optional): The list of email addresses that will receive the message as CC.
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
+            use_html (bool): The boolean value when you want to use body in html format.
 
         Note:
             This method can only be used with an **SMTP** server configured.
         """
         to = to_addrs or [msg.from_]
-        reply_msg = self.__build_message(text_content, to, cc_addrs, bcc_addrs, attachments)
+        reply_msg = self.__build_message(text_content, to, cc_addrs, bcc_addrs, attachments, use_html=use_html)
         reply_msg["References"] = reply_msg["In-Reply-To"] = msg.uid
         reply_msg["Subject"] = "Re: " + msg.subject
         self._smtp_mail.send_message(reply_msg)
 
-    def reply_to_all(self, msg: MailMessage, text_content: str, attachments: List[str] = None) -> None:
+    def reply_to_all(self, msg: MailMessage, text_content: str, attachments: List[str] = None,
+                     use_html: bool = False) -> None:
         """
         Replies to all email addresses included in the original message.
 
@@ -364,6 +370,7 @@ class BotEmailPlugin:
             text_content (str): The content of the email body.
             attachments (List[str], optional): The list with the paths of the files that will be sent
                 as attachments.
+            use_html (bool): The boolean value when you want to use body in html format.
 
         Note:
             This method can only be used with an **SMTP** server configured.
@@ -371,11 +378,11 @@ class BotEmailPlugin:
         emails_addrs = list(msg.to) + list(msg.cc)
         to = [msg.from_]
         cc = [addr for addr in emails_addrs if addr != self._user_email]
-        self.reply(msg, text_content, attachments, to, cc)
+        self.reply(msg, text_content, attachments, to, cc, use_html=use_html)
 
     @if_smtp_configured
     def forward(self, msg: MailMessage, to_addrs: List[str], cc_addrs: List[str] = None,
-                bcc_addrs: List[str] = None, include_attachments=True) -> None:
+                bcc_addrs: List[str] = None, include_attachments=True, use_html: bool = False) -> None:
         """
         Forward a received email message.
 
@@ -385,11 +392,13 @@ class BotEmailPlugin:
             cc_addrs (List[str], optional): The list of email addresses that will receive the message as CC.
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
             include_attachments (boolean, optional): Include attachments from the original message.
+            use_html (bool): The boolean value when you want to use body in html format.
 
         Note:
             This method can only be used with an **SMTP** server configured.
         """
-        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True)
+        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True,
+                                                 use_html=use_html)
         forwarded_message["Subject"] = "Fwd: " + msg.subject
         if include_attachments:
             for part in msg.attachments:
@@ -405,7 +414,7 @@ class BotEmailPlugin:
 
     def __build_message(self, text_content: str, to_addrs: List[str], cc_addrs: List[str] = None,
                         bcc_addrs: List[str] = None, attachments: List[str] = None,
-                        is_forwarded=False) -> MIMEMultipart:
+                        is_forwarded=False, use_html=False) -> MIMEMultipart:
         message = MIMEMultipart()
         message["From"] = self._user_email
 
@@ -421,7 +430,10 @@ class BotEmailPlugin:
             message["Bcc"] = bcc
 
         # Add body to email
-        text_message = MIMEText(text_content, "plain")
+        if use_html:
+            text_message = MIMEText(text_content, "html")
+        else:
+            text_message = MIMEText(text_content, "plain")
         message.attach(text_message)
 
         if is_forwarded:
